==> sense-go-0.14.10.tgz: package/.verb.md <==
<p align="center">
  <a href="https://stefanwalther/sense-go">
    <img src="https://raw.githubusercontent.com/stefanwalther/sense-go/master/docs/images/logo_400x184.png">
  </a>
  <p align="center">Validate, package and deploy your Qlik Sense Visualization Extension projects with ease.</p>
</p>

[![](https://david-dm.org/stefanwalther/sense-go.png)](https://david-dm.org/stefanwalther/sense-go)
[![](https://travis-ci.org/stefanwalther/sense-go.svg?branch=master)](https://travis-ci.org/stefanwalther/sense-go)
[![Build status](https://ci.appveyor.com/api/projects/status/28jsxcoelyuo81fk/branch/master?svg=true)](https://ci.appveyor.com/project/stefanwalther/sense-go/branch/master)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/cd348c2723f54f7398399549225ca2e9)](https://www.codacy.com/app/stefan-walther/sense-go?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=stefanwalther/sense-go&amp;utm_campaign=badger)


## Table of Contents
<details>

<!-- toc -->

</details>

## Motivation
{%= docs('motivation.md') %}

## Installation
{%= docs('installation.md') %}

## Usage
{%= docs('usage.md') %}

## Conventions
{%= docs('conventions.md') %}

## Basic workflow
{%= docs('workflow.md') %}

## API / Programmatic Usage
{%= docs('api.md') %}

## Tasks
{%= docs('tasks.md') %}

## Task Chains
{%= docs('task-chains.md')%}

## Used Gulp plugins
{%= docs('gulp-plugins.md')%}

## About

### Author
{%= docs('author.md') %}

### Contributing
{%= docs('contributing.md')%}

### License
{%= copyright() %}<br/> 
{%= license %}

***

{%= include("footer") %}

==> sense-go-0.14.18.tgz: package/.verb.md <==
<p align="center">
  <a href="https://stefanwalther/sense-go">
    <img src="https://raw.githubusercontent.com/stefanwalther/sense-go/master/docs/images/logo_400x184.png">
  </a>
  <p align="center">Validate, package and deploy your Qlik Sense Visualization Extension projects with ease.</p>
</p>

{%= badge('npm') %}
[![David](https://img.shields.io/david/stefanwalther/{%=name%}.svg)](https://github.com/stefanwalther/{%=name%})
[![Codecov](https://img.shields.io/codecov/c/github/stefanwalther/{%=name%}.svg?logo=codecov)](https://codecov.io/gh/stefanwalther/{%=name%})
[![CircleCI](https://img.shields.io/circleci/project/github/stefanwalther/{%=name%}.svg?logo=circleci)](https://circleci.com/gh/stefanwalther/{%=name%}/tree/master)
[![AppVeyor tests](https://img.shields.io/appveyor/ci/stefanwalther/{%=name%}.svg?logo=appveyor)](https://ci.appveyor.com/project/stefanwalther/{%=name%}/branch/master)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/cd348c2723f54f7398399549225ca2e9)](https://www.codacy.com/app/stefan-walther/sense-go?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=stefanwalther/sense-go&amp;utm_campaign=badger)


## Table of Contents
<details>

<!-- toc -->

</details>

## Motivation
{%= docs('motivation.md') %}

## Installation
{%= docs('installation.md') %}

## Usage
{%= docs('usage.md') %}

## Conventions
{%= docs('conventions.md') %}

## Basic workflow
{%= docs('workflow.md') %}

## API / Programmatic Usage
{%= docs('api.md') %}

## Tasks
{%= docs('tasks.md') %}

## Task Chains
{%= docs('task-chains.md')%}

## Used Gulp plugins
{%= docs('gulp-plugins.md')%}

## About

### Author
{%= docs('author.md') %}

### Contributing
{%= docs('contributing.md')%}

### License
{%= copyright() %}<br/> 
{%= license %}

***

{%= include("footer") %}
